@@ -5,7 +5,7 @@ use warnings;
 package MooX::Press;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.056';
+our $VERSION   = '0.057';
 
 use Types::Standard 1.010000 -is, -types;
 use Types::TypeTiny qw(ArrayLike HashLike);
@@ -1089,7 +1089,7 @@ sub install_attributes {
 		}
 		
 		%spec = (%spec_hints, %spec);
-		$spec{is} ||= $opts->{default_is};
+		$spec{is} ||= ($opts->{default_is} || 'ro');
 		
 		if ($spec{is} eq 'lazy') {
 			$spec{is}   = 'ro';
